@@ -9,9 +9,10 @@ Iterate benchmark tests.
 """
 import numpy as np
 
-from benchmarks import ARTIFICIAL_DIM_SIZE
 from iris import coords, cube, iterate
 
+from . import ARTIFICIAL_DIM_SIZE
+
 
 def setup():
     """General variables needed by multiple benchmark classes."""
