@@ -398,7 +398,7 @@ def _calendar_rules(cube, pp):
     if time_coord is not None:
         if time_coord.units.calendar == "360_day":
             pp.lbtim.ic = 2
-        elif time_coord.units.calendar == "gregorian":
+        elif time_coord.units.calendar == "standard":
             pp.lbtim.ic = 1
         elif time_coord.units.calendar == "365_day":
             pp.lbtim.ic = 4
@@ -422,7 +422,16 @@ def _grid_and_pole_rules(cube, pp):
     lat_coord = vector_coord(cube, "latitude")
     grid_lat_coord = vector_coord(cube, "grid_latitude")
 
-    if lon_coord and not is_regular(lon_coord):
+    scalar_lon_coord = scalar_coord(cube, "longitude")
+
+    if lon_coord is None and grid_lon_coord is None and scalar_lon_coord:
+        # default value of 360.0 degrees to specify a circular wrap of
+        # the collapsed scalar longitude coordinate, based on examples
+        # of model output for several different diagnostics
+        pp.bdx = (unit := scalar_lon_coord.units) and unit.modulus or 360.0
+        pp.bzx = scalar_lon_coord.points[0] - pp.bdx
+        pp.lbnpt = scalar_lon_coord.shape[0]
+    elif lon_coord and not is_regular(lon_coord):
         pp.bzx = 0
         pp.bdx = 0
         pp.lbnpt = lon_coord.shape[0]
