@@ -11,15 +11,8 @@ Provides testing capabilities and customisations specific to Iris.
 
 The primary class for this module is :class:`IrisTest`.
 
-By default, this module sets the matplotlib backend to "agg". But when
-this module is imported it checks ``sys.argv`` for the flag "-d". If
-found, it is removed from ``sys.argv`` and the matplotlib backend is
-switched to "tkagg" to allow the interactive visual inspection of
-graphical test results.
-
 """
 
-import codecs
 import collections
 from collections.abc import Mapping
 import contextlib
@@ -34,44 +27,29 @@ import json
 import math
 import os
 import os.path
+from pathlib import Path
 import re
 import shutil
 import subprocess
 import sys
-import threading
-from typing import Dict, List
+from typing import AnyStr
 import unittest
 from unittest import mock
 import warnings
 import xml.dom.minidom
 import zlib
 
-import filelock
 import numpy as np
 import numpy.ma as ma
 import requests
 
 import iris.config
 import iris.cube
+import iris.tests.graphics as graphics
 import iris.util
 
-# Test for availability of matplotlib.
-# (And remove matplotlib as an iris.tests dependency.)
-try:
-    import matplotlib
+MPL_AVAILABLE = graphics.MPL_AVAILABLE
 
-    # Override any user settings e.g. from matplotlibrc file.
-    matplotlib.rcdefaults()
-    # Set backend *after* rcdefaults, as we don't want that overridden (#3846).
-    matplotlib.use("agg")
-    # Standardise the figure size across matplotlib versions.
-    # This permits matplotlib png image comparison.
-    matplotlib.rcParams["figure.figsize"] = [8.0, 6.0]
-    import matplotlib.pyplot as plt
-except ImportError:
-    MPL_AVAILABLE = False
-else:
-    MPL_AVAILABLE = True
 
 try:
     from osgeo import gdal  # noqa
@@ -111,10 +89,6 @@ except ImportError:
 
 #: Basepath for test results.
 _RESULT_PATH = os.path.join(os.path.dirname(__file__), "results")
-#: Default perceptual hash size.
-_HASH_SIZE = 16
-#: Default maximum perceptual hash hamming distance.
-_HAMMING_DISTANCE = 2
 
 if "--data-files-used" in sys.argv:
     sys.argv.remove("--data-files-used")
@@ -131,18 +105,6 @@ if "--create-missing" in sys.argv:
     os.environ["IRIS_TEST_CREATE_MISSING"] = "true"
 
 
-# Whether to display matplotlib output to the screen.
-_DISPLAY_FIGURES = False
-
-if MPL_AVAILABLE and "-d" in sys.argv:
-    sys.argv.remove("-d")
-    plt.switch_backend("tkagg")
-    _DISPLAY_FIGURES = True
-
-# Threading non re-entrant blocking lock to ensure thread-safe plotting.
-_lock = threading.Lock()
-
-
 def main():
     """A wrapper for unittest.main() which adds iris.test specific options to the help (-h) output."""
     if "-h" in sys.argv or "--help" in sys.argv:
@@ -179,41 +141,71 @@ def main():
         unittest.main()
 
 
-def get_data_path(relative_path):
+def _assert_masked_array(assertion, a, b, strict, **kwargs):
+    # Compare masks.
+    a_mask, b_mask = ma.getmaskarray(a), ma.getmaskarray(b)
+    np.testing.assert_array_equal(a_mask, b_mask)
+
+    if strict:
+        # Compare all data values.
+        assertion(a.data, b.data, **kwargs)
+    else:
+        # Compare only unmasked data values.
+        assertion(
+            ma.compressed(a),
+            ma.compressed(b),
+            **kwargs,
+        )
+
+
+def assert_masked_array_equal(a, b, strict=False):
     """
-    Return the absolute path to a data file when given the relative path
-    as a string, or sequence of strings.
+    Check that masked arrays are equal. This requires the
+    unmasked values and masks to be identical.
+
+    Args:
+
+    * a, b (array-like):
+        Two arrays to compare.
+
+    Kwargs:
+
+    * strict (bool):
+        If True, perform a complete mask and data array equality check.
+        If False (default), the data array equality considers only unmasked
+        elements.
 
     """
-    if not isinstance(relative_path, str):
-        relative_path = os.path.join(*relative_path)
-    test_data_dir = iris.config.TEST_DATA_DIR
-    if test_data_dir is None:
-        test_data_dir = ""
-    data_path = os.path.join(test_data_dir, relative_path)
+    _assert_masked_array(np.testing.assert_array_equal, a, b, strict)
 
-    if _EXPORT_DATAPATHS_FILE is not None:
-        _EXPORT_DATAPATHS_FILE.write(data_path + "\n")
 
-    if isinstance(data_path, str) and not os.path.exists(data_path):
-        # if the file is gzipped, ungzip it and return the path of the ungzipped
-        # file.
-        gzipped_fname = data_path + ".gz"
-        if os.path.exists(gzipped_fname):
-            with gzip.open(gzipped_fname, "rb") as gz_fh:
-                try:
-                    with open(data_path, "wb") as fh:
-                        fh.writelines(gz_fh)
-                except IOError:
-                    # Put ungzipped data file in a temporary path, since we
-                    # can't write to the original path (maybe it is owned by
-                    # the system.)
-                    _, ext = os.path.splitext(data_path)
-                    data_path = iris.util.create_temp_filename(suffix=ext)
-                    with open(data_path, "wb") as fh:
-                        fh.writelines(gz_fh)
+def assert_masked_array_almost_equal(a, b, decimal=6, strict=False):
+    """
+    Check that masked arrays are almost equal. This requires the
+    masks to be identical, and the unmasked values to be almost
+    equal.
 
-    return data_path
+    Args:
+
+    * a, b (array-like):
+        Two arrays to compare.
+
+    Kwargs:
+
+    * strict (bool):
+        If True, perform a complete mask and data array equality check.
+        If False (default), the data array equality considers only unmasked
+        elements.
+
+    * decimal (int):
+        Equality tolerance level for
+        :meth:`numpy.testing.assert_array_almost_equal`, with the meaning
+        'abs(desired-actual) < 0.5 * 10**(-decimal)'
+
+    """
+    _assert_masked_array(
+        np.testing.assert_array_almost_equal, a, b, strict, decimal=decimal
+    )
 
 
 class IrisTest_nometa(unittest.TestCase):
@@ -221,11 +213,6 @@ class IrisTest_nometa(unittest.TestCase):
 
     _assertion_counts = collections.defaultdict(int)
 
-    @classmethod
-    def setUpClass(cls):
-        # Ensure that the CF profile if turned-off for testing.
-        iris.site_configuration["cf_profile"] = None
-
     def _assert_str_same(
         self,
         reference_str,
@@ -250,6 +237,43 @@ class IrisTest_nometa(unittest.TestCase):
                 % (type_comparison_name, reference_filename, diff)
             )
 
+    @staticmethod
+    def get_data_path(relative_path):
+        """
+        Return the absolute path to a data file when given the relative path
+        as a string, or sequence of strings.
+
+        """
+        if not isinstance(relative_path, str):
+            relative_path = os.path.join(*relative_path)
+        test_data_dir = iris.config.TEST_DATA_DIR
+        if test_data_dir is None:
+            test_data_dir = ""
+        data_path = os.path.join(test_data_dir, relative_path)
+
+        if _EXPORT_DATAPATHS_FILE is not None:
+            _EXPORT_DATAPATHS_FILE.write(data_path + "\n")
+
+        if isinstance(data_path, str) and not os.path.exists(data_path):
+            # if the file is gzipped, ungzip it and return the path of the ungzipped
+            # file.
+            gzipped_fname = data_path + ".gz"
+            if os.path.exists(gzipped_fname):
+                with gzip.open(gzipped_fname, "rb") as gz_fh:
+                    try:
+                        with open(data_path, "wb") as fh:
+                            fh.writelines(gz_fh)
+                    except IOError:
+                        # Put ungzipped data file in a temporary path, since we
+                        # can't write to the original path (maybe it is owned by
+                        # the system.)
+                        _, ext = os.path.splitext(data_path)
+                        data_path = iris.util.create_temp_filename(suffix=ext)
+                        with open(data_path, "wb") as fh:
+                            fh.writelines(gz_fh)
+
+        return data_path
+
     @staticmethod
     def get_result_path(relative_path):
         """
@@ -261,25 +285,6 @@ class IrisTest_nometa(unittest.TestCase):
             relative_path = os.path.join(*relative_path)
         return os.path.abspath(os.path.join(_RESULT_PATH, relative_path))
 
-    def assertStringEqual(
-        self, reference_str, test_str, type_comparison_name="strings"
-    ):
-        if reference_str != test_str:
-            diff = "\n".join(
-                difflib.unified_diff(
-                    reference_str.splitlines(),
-                    test_str.splitlines(),
-                    "Reference",
-                    "Test result",
-                    "",
-                    "",
-                    0,
-                )
-            )
-            self.fail(
-                "{} do not match:\n{}".format(type_comparison_name, diff)
-            )
-
     def result_path(self, basename=None, ext=""):
         """
         Return the full path to a test result, generated from the \
@@ -373,8 +378,8 @@ class IrisTest_nometa(unittest.TestCase):
             flags = list(map(str, flags))
 
         try:
-            # Python3 only: use subprocess.run()
-            args = ["ncdump"] + flags + [netcdf_filename]
+            exe_path = env_bin_path("ncdump")
+            args = [exe_path] + flags + [netcdf_filename]
             cdl = subprocess.check_output(args, stderr=subprocess.STDOUT)
         except subprocess.CalledProcessError as exc:
             print(exc.output)
@@ -598,16 +603,6 @@ class IrisTest_nometa(unittest.TestCase):
         expr = re.compile(expected_regexp)
         matches.extend(message for message in messages if expr.search(message))
 
-    @contextlib.contextmanager
-    def assertWarnsRegexp(self, expected_regexp=""):
-        # Check that a warning is raised matching a given expression.
-        with self._recordWarningMatches(expected_regexp) as matches:
-            yield
-
-        msg = "Warning matching '{}' not raised."
-        msg = msg.format(expected_regexp)
-        self.assertTrue(matches, msg)
-
     @contextlib.contextmanager
     def assertLogs(self, logger=None, level=None, msg_regex=None):
         """
@@ -654,85 +649,14 @@ class IrisTest_nometa(unittest.TestCase):
         msg = msg.format(expected_regexp, matches)
         self.assertFalse(matches, msg)
 
-    def _assertMaskedArray(self, assertion, a, b, strict, **kwargs):
-        # Define helper function to extract unmasked values as a 1d
-        # array.
-        def unmasked_data_as_1d_array(array):
-            array = ma.asarray(array)
-            if array.ndim == 0:
-                if array.mask:
-                    data = np.array([])
-                else:
-                    data = np.array([array.data])
-            else:
-                data = array.data[~ma.getmaskarray(array)]
-            return data
-
-        # Compare masks. This will also check that the array shapes
-        # match, which is not tested when comparing unmasked values if
-        # strict is False.
-        a_mask, b_mask = ma.getmaskarray(a), ma.getmaskarray(b)
-        np.testing.assert_array_equal(a_mask, b_mask)
-
-        if strict:
-            assertion(a.data, b.data, **kwargs)
-        else:
-            assertion(
-                unmasked_data_as_1d_array(a),
-                unmasked_data_as_1d_array(b),
-                **kwargs,
-            )
-
-    def assertMaskedArrayEqual(self, a, b, strict=False):
-        """
-        Check that masked arrays are equal. This requires the
-        unmasked values and masks to be identical.
-
-        Args:
-
-        * a, b (array-like):
-            Two arrays to compare.
-
-        Kwargs:
-
-        * strict (bool):
-            If True, perform a complete mask and data array equality check.
-            If False (default), the data array equality considers only unmasked
-            elements.
-
-        """
-        self._assertMaskedArray(np.testing.assert_array_equal, a, b, strict)
+    assertMaskedArrayEqual = staticmethod(assert_masked_array_equal)
 
     def assertArrayAlmostEqual(self, a, b, decimal=6):
         np.testing.assert_array_almost_equal(a, b, decimal=decimal)
 
-    def assertMaskedArrayAlmostEqual(self, a, b, decimal=6, strict=False):
-        """
-        Check that masked arrays are almost equal. This requires the
-        masks to be identical, and the unmasked values to be almost
-        equal.
-
-        Args:
-
-        * a, b (array-like):
-            Two arrays to compare.
-
-        Kwargs:
-
-        * strict (bool):
-            If True, perform a complete mask and data array equality check.
-            If False (default), the data array equality considers only unmasked
-            elements.
-
-        * decimal (int):
-            Equality tolerance level for
-            :meth:`numpy.testing.assert_array_almost_equal`, with the meaning
-            'abs(desired-actual) < 0.5 * 10**(-decimal)'
-
-        """
-        self._assertMaskedArray(
-            np.testing.assert_array_almost_equal, a, b, strict, decimal=decimal
-        )
+    assertMaskedArrayAlmostEqual = staticmethod(
+        assert_masked_array_almost_equal
+    )
 
     def assertArrayAllClose(self, a, b, rtol=1.0e-7, atol=1.0e-8, **kwargs):
         """
@@ -872,137 +796,10 @@ class IrisTest_nometa(unittest.TestCase):
         output directory, and the imagerepo.json file being updated.
 
         """
-        from PIL import Image
-        import imagehash
-
-        dev_mode = os.environ.get("IRIS_TEST_CREATE_MISSING")
-        unique_id = self._unique_id()
-        repo_fname = os.path.join(_RESULT_PATH, "imagerepo.json")
-        with open(repo_fname, "rb") as fi:
-            repo: Dict[str, List[str]] = json.load(
-                codecs.getreader("utf-8")(fi)
-            )
-
-        try:
-            #: The path where the images generated by the tests should go.
-            image_output_directory = os.path.join(
-                os.path.dirname(__file__), "result_image_comparison"
-            )
-            if not os.access(image_output_directory, os.W_OK):
-                if not os.access(os.getcwd(), os.W_OK):
-                    raise IOError(
-                        "Write access to a local disk is required "
-                        "to run image tests.  Run the tests from a "
-                        "current working directory you have write "
-                        "access to to avoid this issue."
-                    )
-                else:
-                    image_output_directory = os.path.join(
-                        os.getcwd(), "iris_image_test_output"
-                    )
-            result_fname = os.path.join(
-                image_output_directory, "result-" + unique_id + ".png"
-            )
-
-            if not os.path.isdir(image_output_directory):
-                # Handle race-condition where the directories are
-                # created sometime between the check above and the
-                # creation attempt below.
-                try:
-                    os.makedirs(image_output_directory)
-                except OSError as err:
-                    # Don't care about "File exists"
-                    if err.errno != 17:
-                        raise
-
-            def _create_missing():
-                fname = "{}.png".format(phash)
-                base_uri = (
-                    "https://scitools.github.io/test-iris-imagehash/"
-                    "images/v4/{}"
-                )
-                uri = base_uri.format(fname)
-                hash_fname = os.path.join(image_output_directory, fname)
-                uris = repo.setdefault(unique_id, [])
-                uris.append(uri)
-                print("Creating image file: {}".format(hash_fname))
-                figure.savefig(hash_fname)
-                msg = "Creating imagerepo entry: {} -> {}"
-                print(msg.format(unique_id, uri))
-                lock = filelock.FileLock(
-                    os.path.join(_RESULT_PATH, "imagerepo.lock")
-                )
-                # The imagerepo.json file is a critical resource, so ensure
-                # thread safe read/write behaviour via platform independent
-                # file locking.
-                with lock.acquire(timeout=600):
-                    with open(repo_fname, "wb") as fo:
-                        json.dump(
-                            repo,
-                            codecs.getwriter("utf-8")(fo),
-                            indent=4,
-                            sort_keys=True,
-                        )
-
-            # Calculate the test result perceptual image hash.
-            buffer = io.BytesIO()
-            figure = plt.gcf()
-            figure.savefig(buffer, format="png")
-            buffer.seek(0)
-            phash = imagehash.phash(Image.open(buffer), hash_size=_HASH_SIZE)
-
-            if unique_id not in repo:
-                # The unique id might not be fully qualified, e.g.
-                # expects iris.tests.test_quickplot.TestLabels.test_contour.0,
-                # but got test_quickplot.TestLabels.test_contour.0
-                # if we find single partial match from end of the key
-                # then use that, else fall back to the unknown id state.
-                matches = [key for key in repo if key.endswith(unique_id)]
-                if len(matches) == 1:
-                    unique_id = matches[0]
-
-            if unique_id in repo:
-                uris = repo[unique_id]
-                # Extract the hex basename strings from the uris.
-                hexes = [
-                    os.path.splitext(os.path.basename(uri))[0] for uri in uris
-                ]
-                # Create the expected perceptual image hashes from the uris.
-                to_hash = imagehash.hex_to_hash
-                expected = [to_hash(uri_hex) for uri_hex in hexes]
-
-                # Calculate hamming distance vector for the result hash.
-                distances = [e - phash for e in expected]
-
-                if np.all([hd > _HAMMING_DISTANCE for hd in distances]):
-                    if dev_mode:
-                        _create_missing()
-                    else:
-                        figure.savefig(result_fname)
-                        msg = (
-                            "Bad phash {} with hamming distance {} "
-                            "for test {}."
-                        )
-                        msg = msg.format(phash, distances, unique_id)
-                        if _DISPLAY_FIGURES:
-                            emsg = "Image comparison would have failed: {}"
-                            print(emsg.format(msg))
-                        else:
-                            emsg = "Image comparison failed: {}"
-                            raise AssertionError(emsg.format(msg))
-            else:
-                if dev_mode:
-                    _create_missing()
-                else:
-                    figure.savefig(result_fname)
-                    emsg = "Missing image test result: {}."
-                    raise AssertionError(emsg.format(unique_id))
-
-            if _DISPLAY_FIGURES:
-                plt.show()
-
-        finally:
-            plt.close()
+        graphics.check_graphic(
+            self._unique_id(),
+            _RESULT_PATH,
+        )
 
     def _remove_testcase_patches(self):
         """Helper to remove per-testcase patches installed by :meth:`patch`."""
@@ -1214,37 +1011,15 @@ class IrisTest(IrisTest_nometa, metaclass=_TestTimingsMetaclass):
     pass
 
 
+get_data_path = IrisTest.get_data_path
 get_result_path = IrisTest.get_result_path
 
 
-class GraphicsTestMixin:
-
-    # nose directive: dispatch tests concurrently.
-    _multiprocess_can_split_ = True
-
-    def setUp(self):
-        # Acquire threading non re-entrant blocking lock to ensure
-        # thread-safe plotting.
-        _lock.acquire()
-        # Make sure we have no unclosed plots from previous tests before
-        # generating this one.
-        if MPL_AVAILABLE:
-            plt.close("all")
-
-    def tearDown(self):
-        # If a plotting test bombs out it can leave the current figure
-        # in an odd state, so we make sure it's been disposed of.
-        if MPL_AVAILABLE:
-            plt.close("all")
-        # Release the non re-entrant blocking lock.
-        _lock.release()
-
-
-class GraphicsTest(GraphicsTestMixin, IrisTest):
+class GraphicsTest(graphics.GraphicsTestMixin, IrisTest):
     pass
 
 
-class GraphicsTest_nometa(GraphicsTestMixin, IrisTest_nometa):
+class GraphicsTest_nometa(graphics.GraphicsTestMixin, IrisTest_nometa):
     # Graphicstest without the metaclass providing test timings.
     pass
 
@@ -1290,23 +1065,7 @@ def skip_gdal(fn):
     return skip(fn)
 
 
-def skip_plot(fn):
-    """
-    Decorator to choose whether to run tests, based on the availability of the
-    matplotlib library.
-
-    Example usage:
-        @skip_plot
-        class MyPlotTests(test.GraphicsTest):
-            ...
-
-    """
-    skip = unittest.skipIf(
-        condition=not MPL_AVAILABLE,
-        reason="Graphics tests require the matplotlib library.",
-    )
-
-    return skip(fn)
+skip_plot = graphics.skip_plot
 
 
 skip_sample_data = unittest.skipIf(
@@ -1352,3 +1111,30 @@ def no_warnings(func):
         return result
 
     return wrapped
+
+
+def env_bin_path(exe_name: AnyStr = None):
+    """
+    Return a Path object for (an executable in) the environment bin directory.
+
+    Parameters
+    ----------
+    exe_name : str
+        If set, the name of an executable to append to the path.
+
+    Returns
+    -------
+    exe_path : Path
+        A path to the bin directory, or an executable file within it.
+
+    Notes
+    -----
+    For use in tests which spawn commands which should call executables within
+    the Python environment, since many IDEs (Eclipse, PyCharm) don't
+    automatically include this location in $PATH (as opposed to $PYTHONPATH).
+    """
+    exe_path = Path(os.__file__)
+    exe_path = (exe_path / "../../../bin").resolve()
+    if exe_name is not None:
+        exe_path = exe_path / exe_name
+    return exe_path
