@@ -10,7 +10,7 @@ Tests for :func:`iris.experimental.regrid.regrid_conservative_via_esmpy`.
 
 # import iris tests first so that some things can be initialised
 # before importing anything else.
-import iris.tests as tests
+import iris.tests as tests  # isort:skip
 
 import contextlib
 import unittest
@@ -33,7 +33,6 @@ import iris.analysis.cartography as i_cartog
 from iris.experimental.regrid_conservative import regrid_conservative_via_esmpy
 import iris.tests.stock as istk
 
-
 _PLAIN_GEODETIC_CS = iris.coord_systems.GeogCS(
     i_cartog.DEFAULT_SPHERICAL_EARTH_RADIUS
 )
@@ -675,7 +674,7 @@ class TestConservativeRegrid(tests.IrisTest):
                 [100, 100, 100, 100, 100, 100, 100, 100, 100],
                 [100, 100, 100, 100, 100, 100, 100, 100, 100],
             ],
-            dtype=np.float,
+            dtype=np.float64,
         )
 
         c1_areasum = _cube_area_sum(c1)
@@ -715,7 +714,7 @@ class TestConservativeRegrid(tests.IrisTest):
                 [100, 100, 199, 199, 100],
                 [100, 100, 199, 199, 199],
             ],
-            dtype=np.float,
+            dtype=np.float64,
         )
         c2_areasum = _cube_area_sum(c2)
 
@@ -770,7 +769,7 @@ class TestConservativeRegrid(tests.IrisTest):
                     [100, 100, 100, 100, 100, 100, 100, 100, 100],
                     [100, 100, 100, 100, 100, 100, 100, 100, 100],
                 ],
-                dtype=np.float,
+                dtype=np.float64,
             )
 
             if do_add_missing:
