@@ -11,8 +11,12 @@ Test the cf module.
 # import iris tests first so that some things can be initialised before importing anything else
 import iris.tests as tests  # isort:skip
 
+import contextlib
+import io
 from unittest import mock
 
+import pytest
+
 import iris
 import iris.fileformats.cf as cf
 
@@ -50,11 +54,14 @@ class TestCaching(tests.IrisTest):
 
 @tests.skip_data
 class TestCFReader(tests.IrisTest):
-    def setUp(self):
+    @pytest.fixture(autouse=True)
+    def set_up(self):
         filename = tests.get_data_path(
             ("NetCDF", "rotated", "xyt", "small_rotPole_precipitation.nc")
         )
         self.cfr = cf.CFReader(filename)
+        with self.cfr:
+            yield
 
     def test_ancillary_variables_pass_0(self):
         self.assertEqual(self.cfr.cf_group.ancillary_variables, {})
@@ -267,6 +274,34 @@ class TestCFReader(tests.IrisTest):
             ),
         )
 
+    def test_destructor(self):
+        """Test the destructor when reading the dataset fails.
+        Related to issue #3312: previously, the `CFReader` would
+        always call `close()` on its `_dataset` attribute, even if it
+        didn't exist because opening the dataset had failed.
+        """
+        with self.temp_filename(suffix=".nc") as fn:
+
+            with open(fn, "wb+") as fh:
+
+                fh.write(
+                    b"\x89HDF\r\n\x1a\nBroken file with correct signature"
+                )
+                fh.flush()
+
+                with io.StringIO() as buf:
+                    with contextlib.redirect_stderr(buf):
+                        try:
+                            _ = cf.CFReader(fn)
+                        except OSError:
+                            pass
+                        try:
+                            _ = iris.load_cubes(fn)
+                        except OSError:
+                            pass
+                    buf.seek(0)
+                    self.assertMultiLineEqual("", buf.read())
+
 
 @tests.skip_data
 class TestLoad(tests.IrisTest):
@@ -320,7 +355,8 @@ class TestLoad(tests.IrisTest):
 
 @tests.skip_data
 class TestClimatology(tests.IrisTest):
-    def setUp(self):
+    @pytest.fixture(autouse=True)
+    def set_up(self):
         filename = tests.get_data_path(
             (
                 "NetCDF",
@@ -329,6 +365,8 @@ class TestClimatology(tests.IrisTest):
             )
         )
         self.cfr = cf.CFReader(filename)
+        with self.cfr:
+            yield
 
     def test_bounds(self):
         time = self.cfr.cf_group["temp_dmax_tmean_abs"].cf_group.coordinates[
@@ -345,7 +383,8 @@ class TestClimatology(tests.IrisTest):
 
 @tests.skip_data
 class TestLabels(tests.IrisTest):
-    def setUp(self):
+    @pytest.fixture(autouse=True)
+    def set_up(self):
         filename = tests.get_data_path(
             (
                 "NetCDF",
@@ -360,6 +399,10 @@ class TestLabels(tests.IrisTest):
         )
         self.cfr_end = cf.CFReader(filename)
 
+        with self.cfr_start:
+            with self.cfr_end:
+                yield
+
     def test_label_dim_start(self):
         cf_data_var = self.cfr_start.cf_group["temp_dmax_tmean_abs"]
 
