@@ -16,9 +16,10 @@ import unittest.mock as mock
 
 import dask.array as da
 import numpy as np
+import pytest
 
 from iris._lazy_data import as_lazy_data, is_lazy_data
-from iris.common.metadata import BaseMetadata
+from iris.common.metadata import BaseMetadata, CoordMetadata
 from iris.coords import AuxCoord, Coord
 from iris.cube import Cube
 from iris.experimental.ugrid.mesh import Connectivity, Mesh, MeshCoord
@@ -45,16 +46,11 @@ class Test___init__(tests.IrisTest):
         # underlying mesh coordinate.
         for axis in Mesh.AXES:
             meshcoord = sample_meshcoord(axis=axis)
-            # N.B.
-            node_x_coord = meshcoord.mesh.coord(include_nodes=True, axis=axis)
-            for key in node_x_coord.metadata._fields:
+            face_x_coord = meshcoord.mesh.coord(include_faces=True, axis=axis)
+            for key in face_x_coord.metadata._fields:
                 meshval = getattr(meshcoord, key)
-                if key == "var_name":
-                    # var_name is unused.
-                    self.assertIsNone(meshval)
-                else:
-                    # names, units and attributes are derived from the node coord.
-                    self.assertEqual(meshval, getattr(node_x_coord, key))
+                # All relevant attributes are derived from the face coord.
+                self.assertEqual(meshval, getattr(face_x_coord, key))
 
     def test_fail_bad_mesh(self):
         with self.assertRaisesRegex(TypeError, "must be a.*Mesh"):
@@ -270,10 +266,11 @@ class Test__str_repr(tests.IrisTest):
     def _expected_elements_regexp(
         self,
         standard_name="longitude",
-        long_name="long-name",
-        attributes=True,
+        long_name=None,
+        attributes=False,
         location="face",
         axis="x",
+        var_name=None,
     ):
         # Printed name is standard or long -- we don't have a case with neither
         coord_name = standard_name or long_name
@@ -282,24 +279,30 @@ class Test__str_repr(tests.IrisTest):
         regexp = f"MeshCoord :  {coord_name} / [^\n]+\n *"
         regexp += r"mesh: \<Mesh: 'test_mesh'>\n *"
         regexp += f"location: '{location}'\n *"
+
         # Now some optional sections : whichever comes first will match
         # arbitrary content leading up to it.
-        matched_any_upto = False
-        if standard_name:
-            regexp += ".*"
-            matched_any_upto = True
-            regexp += f"standard_name: '{standard_name}'\n *"
-        if long_name:
+        matched_upto = False
+
+        def upto_first_expected(regexp, matched_any_upto):
             if not matched_any_upto:
                 regexp += ".*"
                 matched_any_upto = True
+            return regexp, matched_any_upto
+
+        if standard_name:
+            regexp, matched_upto = upto_first_expected(regexp, matched_upto)
+            regexp += f"standard_name: '{standard_name}'\n *"
+        if long_name:
+            regexp, matched_upto = upto_first_expected(regexp, matched_upto)
             regexp += f"long_name: '{long_name}'\n *"
+        if var_name:
+            regexp, matched_upto = upto_first_expected(regexp, matched_upto)
+            regexp += f"var_name: '{var_name}'\n *"
         if attributes:
             # if we expected attributes, they should come next
             # TODO: change this when each attribute goes on a new line
-            if not matched_any_upto:
-                regexp += ".*"
-                matched_any_upto = True
+            regexp, matched_upto = upto_first_expected(regexp, matched_upto)
             # match 'attributes:' followed by N*lines with larger indent
             regexp += "attributes:(\n        [^ \n]+ +[^ \n]+)+\n    "
         # After those items, expect 'axis' next
@@ -314,7 +317,7 @@ class Test__str_repr(tests.IrisTest):
         # A simple check for the condensed form.
         result = repr(self.meshcoord)
         expected = (
-            "<MeshCoord: longitude / (degrees_east)  "
+            "<MeshCoord: longitude / (unknown)  "
             "mesh(test_mesh) location(face)  [...]+bounds  shape(3,)>"
         )
         self.assertEqual(expected, result)
@@ -331,7 +334,7 @@ class Test__str_repr(tests.IrisTest):
         self.assertTrue(self.meshcoord.has_lazy_bounds())
 
         expected = (
-            "<MeshCoord: longitude / (degrees_east)  "
+            "<MeshCoord: longitude / (unknown)  "
             "mesh(test_mesh) location(face)  <lazy>+bounds  shape(3,)>"
         )
         self.assertEqual(expected, result)
@@ -342,7 +345,7 @@ class Test__str_repr(tests.IrisTest):
         assert self.mesh.name() == "unknown"
         result = repr(self.meshcoord)
         re_expected = (
-            r".MeshCoord: longitude / \(degrees_east\)  "
+            r".MeshCoord: longitude / \(unknown\)  "
             r"mesh\(.Mesh object at 0x[^>]+.\) location\(face\) "
         )
         self.assertRegex(result, re_expected)
@@ -392,18 +395,6 @@ class Test__str_repr(tests.IrisTest):
         re_expected = self._expected_elements_regexp(long_name=False)
         self.assertRegex(result, re_expected)
 
-    def test_str_no_standard_name(self):
-        mesh = self.mesh
-        # Remove the standard_name of the node coord in the mesh.
-        node_coord = mesh.coord(include_nodes=True, axis="x")
-        node_coord.standard_name = None
-        node_coord.axis = "x"  # This is required : but it's a kludge !!
-        # Make a new meshcoord, based on the modified mesh.
-        meshcoord = sample_meshcoord(mesh=self.mesh)
-        result = str(meshcoord)
-        re_expected = self._expected_elements_regexp(standard_name=False)
-        self.assertRegex(result, re_expected)
-
     def test_str_no_attributes(self):
         mesh = self.mesh
         # No attributes on the node coord in the mesh.
@@ -451,9 +442,11 @@ class Test_cube_containment(tests.IrisTest):
 
     def test_find_by_name(self):
         meshcoord = self.meshcoord
+        # hack to give it a long name
+        meshcoord.long_name = "odd_case"
         cube = self.cube
         self.assertIs(cube.coord(standard_name="longitude"), meshcoord)
-        self.assertIs(cube.coord(long_name="long-name"), meshcoord)
+        self.assertIs(cube.coord(long_name="odd_case"), meshcoord)
 
     def test_find_by_axis(self):
         meshcoord = self.meshcoord
@@ -796,5 +789,157 @@ class Test_MeshCoord__dataviews(tests.IrisTest):
         self._check_bounds_bad_index_values(lazy=True)
 
 
+class Test__metadata:
+    def setup_mesh(self, location, axis):
+        # Create a standard test mesh + attach it to the test instance.
+        mesh = sample_mesh()
+
+        # Modify the metadata of specific coordinates used in this test.
+        def select_coord(location, axis):
+            kwargs = {f"include_{location}s": True, "axis": axis}
+            return mesh.coord(**kwargs)
+
+        node_coord = select_coord("node", axis)
+        location_coord = select_coord(location, axis)
+        for i_place, coord in enumerate((node_coord, location_coord)):
+            coord.standard_name = "longitude" if axis == "x" else "latitude"
+            coord.units = "degrees"
+            coord.long_name = f"long_name_{i_place}"
+            coord.var_name = f"var_name_{i_place}"
+            coord.attributes = {"att": i_place}
+
+        # attach all the relevant testcase context to the test instance.
+        self.mesh = mesh
+        self.location = location
+        self.axis = axis
+        self.location_coord = location_coord
+        self.node_coord = node_coord
+
+    def coord_metadata_matches(self, test_coord, ref_coord):
+        # Check that two coords match, in all the basic Coord identity/phenomenon
+        # metadata fields -- so it works even between coords of different subclasses.
+        for key in CoordMetadata._fields:
+            assert getattr(test_coord, key) == getattr(ref_coord, key)
+
+    @pytest.fixture(params=["face", "edge"])
+    def location_face_or_edge(self, request):
+        # Fixture to parametrise over location = face/edge
+        return request.param
+
+    @pytest.fixture(params=["x", "y"])
+    def axis_x_or_y(self, request):
+        # Fixture to parametrise over axis = X/Y
+        return request.param
+
+    def test_node_meshcoord(self, axis_x_or_y):
+        # MeshCoord metadata matches that of the relevant node coord.
+        self.setup_mesh(location="node", axis=axis_x_or_y)
+        meshcoord = self.mesh.to_MeshCoord(
+            location=self.location, axis=self.axis
+        )
+        self.coord_metadata_matches(meshcoord, self.node_coord)
+
+    def test_faceedge_basic(self, location_face_or_edge, axis_x_or_y):
+        # MeshCoord metadata matches that of the face/edge ("points") coord.
+        self.setup_mesh(location_face_or_edge, axis_x_or_y)
+        meshcoord = self.mesh.to_MeshCoord(
+            location=self.location, axis=self.axis
+        )
+        self.coord_metadata_matches(meshcoord, self.location_coord)
+
+    @pytest.mark.parametrize(
+        "fieldname", ["long_name", "var_name", "attributes"]
+    )
+    def test_faceedge_dontcare_fields(
+        self, location_face_or_edge, axis_x_or_y, fieldname
+    ):
+        # Check that it's ok for the face/edge and node coords to have different
+        # long-name, var-name or attributes.
+        self.setup_mesh(location_face_or_edge, axis_x_or_y)
+        if fieldname == "attributes":
+            different_value = {"myattrib": "different attributes"}
+        else:
+            # others are just arbitrary strings.
+            different_value = "different"
+        setattr(self.location_coord, fieldname, different_value)
+        # Mostly.. just check this does not cause an error, as it would do if we
+        # modified "standard_name" or "units" (see other tests) ...
+        meshcoord = self.mesh.to_MeshCoord(
+            location=self.location, axis=self.axis
+        )
+        # ... but also, check that the result matches the expected face/edge coord.
+        self.coord_metadata_matches(meshcoord, self.location_coord)
+
+    def test_faceedge_fail_mismatched_stdnames(
+        self, location_face_or_edge, axis_x_or_y
+    ):
+        # Different "standard_name" for node and face/edge causes an error.
+        self.setup_mesh(location_face_or_edge, axis_x_or_y)
+        node_name = f"projection_{axis_x_or_y}_coordinate"
+        self.node_coord.standard_name = node_name
+        location_name = "longitude" if axis_x_or_y == "x" else "latitude"
+        msg = (
+            "Node coordinate .*"
+            f"disagrees with the {location_face_or_edge} coordinate .*, "
+            'in having a "standard_name" value of '
+            f"'{node_name}' instead of '{location_name}'"
+        )
+        with pytest.raises(ValueError, match=msg):
+            self.mesh.to_MeshCoord(
+                location=location_face_or_edge, axis=axis_x_or_y
+            )
+
+    def test_faceedge_fail_missing_stdnames(
+        self, location_face_or_edge, axis_x_or_y
+    ):
+        # "standard_name" compared with None also causes an error.
+        self.setup_mesh(location_face_or_edge, axis_x_or_y)
+        self.node_coord.standard_name = None
+        # N.B. in the absence of a standard-name, we **must** provide an extra ".axis"
+        # property, or the coordinate cannot be correctly identified in the Mesh.
+        # This is a bit of a kludge, but works with current code.
+        self.node_coord.axis = axis_x_or_y
+
+        location_name = "longitude" if axis_x_or_y == "x" else "latitude"
+        msg = (
+            "Node coordinate .*"
+            f"disagrees with the {location_face_or_edge} coordinate .*, "
+            'in having a "standard_name" value of '
+            f"None instead of '{location_name}'"
+        )
+        with pytest.raises(ValueError, match=msg):
+            self.mesh.to_MeshCoord(
+                location=location_face_or_edge, axis=axis_x_or_y
+            )
+
+    def test_faceedge_fail_mismatched_units(
+        self, location_face_or_edge, axis_x_or_y
+    ):
+        # Different "units" for node and face/edge causes an error.
+        self.setup_mesh(location_face_or_edge, axis_x_or_y)
+        self.node_coord.units = "hPa"
+        msg = (
+            "Node coordinate .*"
+            f"disagrees with the {location_face_or_edge} coordinate .*, "
+            'in having a "units" value of '
+            "'hPa' instead of 'degrees'"
+        )
+        with pytest.raises(ValueError, match=msg):
+            self.mesh.to_MeshCoord(
+                location=location_face_or_edge, axis=axis_x_or_y
+            )
+
+    def test_faceedge_missing_units(self, location_face_or_edge, axis_x_or_y):
+        # Units compared with a None ("unknown") is not an error.
+        self.setup_mesh(location_face_or_edge, axis_x_or_y)
+        self.node_coord.units = None
+        # This is OK
+        meshcoord = self.mesh.to_MeshCoord(
+            location=self.location, axis=self.axis
+        )
+        # ... but also, check that the result matches the expected face/edge coord.
+        self.coord_metadata_matches(meshcoord, self.location_coord)
+
+
 if __name__ == "__main__":
     tests.main()
